==> tekton-model-triggers-v1alpha1-6.3.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecBindingFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerSpecBindingFluentImpl<A extends TriggerSpecBindingFluent<A>> extends BaseFluent<A> implements TriggerSpecBindingFluent<A>{
  public TriggerSpecBindingFluentImpl() {
  }
  public TriggerSpecBindingFluentImpl(TriggerSpecBinding instance) {
    this.withApiversion(instance.getApiversion()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withRef(instance.getRef()); 
    this.withValue(instance.getValue()); 
  }
  private String apiversion;
  private String kind;
  private String name;
  private String ref;
  private String value;
  public String getApiversion() {
    return this.apiversion;
  }
  public A withApiversion(String apiversion) {
    this.apiversion=apiversion; return (A) this;
  }
  public Boolean hasApiversion() {
    return this.apiversion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerSpecBindingFluentImpl that = (TriggerSpecBindingFluentImpl) o;
    if (apiversion != null ? !apiversion.equals(that.apiversion) :that.apiversion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (ref != null ? !ref.equals(that.ref) :that.ref != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiversion,  kind,  name,  ref,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiversion != null) { sb.append("apiversion:"); sb.append(apiversion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerSpecBindingFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerSpecBindingFluentImpl<A extends TriggerSpecBindingFluent<A>> extends BaseFluent<A> implements TriggerSpecBindingFluent<A>{
  public TriggerSpecBindingFluentImpl() {
  }
  public TriggerSpecBindingFluentImpl(TriggerSpecBinding instance) {
    if (instance != null) {
      this.withApiversion(instance.getApiversion());
      this.withKind(instance.getKind());
      this.withName(instance.getName());
      this.withRef(instance.getRef());
      this.withValue(instance.getValue());
    }
  }
  private String apiversion;
  private String kind;
  private String name;
  private String ref;
  private String value;
  public String getApiversion() {
    return this.apiversion;
  }
  public A withApiversion(String apiversion) {
    this.apiversion=apiversion; return (A) this;
  }
  public Boolean hasApiversion() {
    return this.apiversion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getRef() {
    return this.ref;
  }
  public A withRef(String ref) {
    this.ref=ref; return (A) this;
  }
  public Boolean hasRef() {
    return this.ref != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerSpecBindingFluentImpl that = (TriggerSpecBindingFluentImpl) o;
    if (!java.util.Objects.equals(apiversion, that.apiversion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(ref, that.ref)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiversion,  kind,  name,  ref,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiversion != null) { sb.append("apiversion:"); sb.append(apiversion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (ref != null) { sb.append("ref:"); sb.append(ref + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}
